pub struct Server { /* private fields */ }Expand description
The standard, protocol-agnostic ChatServer implementation.
Construct one with Server::new, attach any number of listeners with
Server::add_listener, then call ChatServer::run:
use chat_system::server::Server;
use chat_system::servers::IrcListener;
use chat_system::ChatServer;
let mut server = Server::new("my-server")
.add_listener(IrcListener::new("0.0.0.0:6667"))
.add_listener(IrcListener::new("0.0.0.0:6697"));
server.run(|msg| async move {
println!("{}: {}", msg.sender, msg.content);
Ok(Some(format!("echo: {}", msg.content)))
}).await?;With the tls feature enabled, you can mix plaintext and TLS listeners:
ⓘ
use chat_system::servers::{IrcListener, TlsIrcListener};
let server = Server::new("my-server")
.add_listener(IrcListener::new("0.0.0.0:6667"))
.add_listener(TlsIrcListener::new("0.0.0.0:6697", tls_config));Implementations
Sourceimpl Server
impl Server
Sourcepub fn add_listener(self, listener: impl ChatListener + 'static) -> Self
pub fn add_listener(self, listener: impl ChatListener + 'static) -> Self
Attach a listener. The listener may speak any protocol.
Listeners must be added before calling ChatServer::run.
Sourcepub fn add_boxed_listener(self, listener: Box<dyn ChatListener>) -> Self
pub fn add_boxed_listener(self, listener: Box<dyn ChatListener>) -> Self
Attach an already-boxed listener.
This is useful when you already have a Box<dyn ChatListener>, for
example from a ListenerConfig::build call.
Listeners must be added before calling ChatServer::run.