Core message types.
Structs
- Media
Attachment - A media attachment in a message.
- Message
- A message received from or sent to a chat platform.
- Reaction
- A single emoji reaction attached to a message, with an aggregate count and the list of user IDs who reacted.
- Send
Options - Options for sending a message with additional metadata.
Enums
- Message
Type - The kind of a message, allowing callers to distinguish between regular text messages and system events.